@@ -4,13 +4,11 @@ import os
 import argparse
 from auterioncli.commands import available_commands
 
-from auterioncli.meta_util import PersistentState, check_for_updates
-
+from auterioncli.meta_util import PersistentState, check_for_updates, get_version
 
 def main():
 
     persistent_state = PersistentState()
-    check_for_updates(persistent_state)
 
     config = {
         "device_address": os.getenv('AUTERION_DEVICE_ADDRESS', "10.41.1.1")
@@ -18,14 +16,26 @@ def main():
     commands = available_commands(config)
 
     main_parser = argparse.ArgumentParser()
-    command_subparsers = main_parser.add_subparsers(title="command", metavar='<command>', dest="_root_command", required=True)
+    main_parser.add_argument('--version', help='Print version of this tool', action='store_true')
+    command_subparsers = main_parser.add_subparsers(title="command", metavar='<command>', dest="root_command")
 
     for name, command in commands.items():
         parser = command_subparsers.add_parser(name, help=command.help())
         command.setup_parser(parser)
 
     args = main_parser.parse_args()
-    commands[args._root_command].run(args)
+
+    if args.version:
+        print(get_version())
+        exit(0)
+
+    if args.root_command is None:
+        main_parser.print_help()
+        exit(1)
+
+    check_for_updates(persistent_state)
+
+    commands[args.root_command].run(args)
 
     persistent_state.persist()
 
